****************************************
Dendrite
****************************************

A ``Dendrite`` is a sub-group of a ``Projection``, gathering the synapses between the pre-synaptic population and a single post-synaptic neuron. 


Class Dendrite
===============================

.. autoclass:: ANNarchy.Dendrite
   :members:

